@@ -277,6 +277,8 @@ class BufferedWindow(wx.Window):
             self.Draw(dc)
             # update the screen
             wx.ClientDC(self).Blit(0, 0, self.Width, self.Height, dc, 0, 0)
+
+
         
 
 #----------------------------------------------------------------------
@@ -771,14 +773,14 @@ class SpeedMeter(BufferedWindow):
         
             if self._extrastyle & SM_ROTATE_TEXT:
                 angis = colourangles[ii] - float(width)/(2.0*radius)
-                x, y = self.CircleCoords(radius-10.0*self.scale, angis, centerX, centerY)
+                x, y = self.CircleCoords(radius-15.0*self.scale, angis, centerX, centerY)
                 dc.DrawRotatedText(strings, x, y, angles)
             else:
                 angis = colourangles[ii]
                 if self._extrastyle & SM_DRAW_FANCY_TICKS == 0:
-                    x, y = self.CircleCoords(radius-10*self.scale, angis, centerX, centerY)
+                    x, y = self.CircleCoords(radius-15*self.scale, angis, centerX, centerY)
                     lX = lX*len(strings)
-                    x = x - lX - width*cos(angis)/2.0
+                    x = x - lX - width*cos(angis)/2.0 + 4 #m
                     y = y - lY - height*sin(angis)/2.0
         
                 if self._extrastyle & SM_DRAW_FANCY_TICKS:
