@@ -107,9 +107,10 @@ class OBDPort:
                 
              except serial.SerialException:
                 self.State = 0
-                
-             self.ELMver = self.get_result()
+#mmmm                
              print self.get_result()
+             self.ELMver = self.get_result()
+
              wx.PostEvent(self._notify_window, DebugEvent([2,"atz response:" + self.ELMver]))
              print "self.state: "+str(self.State)
 
@@ -200,6 +201,7 @@ class OBDPort:
          
          # 9 seems to be the length of the shortest valid response
          if len(code) < 7:
+             print "BogusCode"
              raise "BogusCode"
          
          # get the first thing returned, echo should be off
@@ -211,7 +213,7 @@ class OBDPort:
          code = string.join(code, "")
          
          #cables can behave differently 
-         print "CODE: " + code
+         #print "CODE: " + code
          if code[:6] == "NODATA": # there is no such sensor
              return "NODATA"
          if code[:7] == "STOPPED": # BUSY
@@ -247,7 +249,7 @@ class OBDPort:
          cmd = sensor.cmd
          self.send_command(cmd)
          data = self.get_result()
-         print "data: "+data
+         #print "data: "+data
          
          if data:
              data = self.interpret_result(data)
@@ -261,9 +263,6 @@ class OBDPort:
      # return string of sensor name and value from sensor index
      def sensor(self , sensor_index):
 
-         log1="sensor: "+ str(sensor_index)
-         print log1
-
          """Returns 3-tuple of given sensors. 3-tuple consists of
          (Sensor Name (string), Sensor Value (string), Sensor Unit (string) ) """
          sensor = obd_sensors.SENSORS[sensor_index]
@@ -274,7 +273,6 @@ class OBDPort:
          log2="echo '"+log1+"' >> /home/user/MyDocs/pyobd.log"
          os.popen(log2)
 
-         #print "Sensor unit: " + sensor.unit
          return (sensor.name,r, sensor.unit)
 
      def sensor_names(self):
