@@ -287,9 +287,6 @@ class MyApp(wx.App):
                     wx.PostEvent(self._notify_window, DTCEvent(0)) #clear list
                     DTCCodes=self.port.get_dtc()
 
-
-                    #print DTCCodes
-
                     if len(DTCCodes)==0:
                       wx.PostEvent(self._notify_window, DTCEvent(["","","No DTC codes (codes cleared)"]))
                       log1="Value :  No DTC codes or codes cleared"
@@ -299,7 +296,6 @@ class MyApp(wx.App):
                       log2="echo  >> /home/user/MyDocs/pyobd.log"
                       os.popen(log2)
 
-
                     for i in range (0,len(DTCCodes)):
                       try:
                          wx.PostEvent(self._notify_window, DTCEvent([DTCCodes[i][1],DTCCodes[i][0],pcodes[DTCCodes[i][1]]]))
@@ -319,10 +315,9 @@ class MyApp(wx.App):
                          os.popen(log2)
                          pass
 
-#Gauge
+#Gauges
 		elif curstate==4:
 
-			wx.Yield()
 			speedsensor=13
 			if self.active[speedsensor]:
 				s = self.port.sensor(speedsensor)
@@ -340,7 +335,7 @@ class MyApp(wx.App):
 				s = self.port.sensor(speedsensor)
 				text="rpm"+str(s[1])
 				wx.PostEvent(self._notify_window, DialEvent(text))
-                   
+			wx.Yield()                   
 
                 else:
                  pass 
@@ -533,7 +528,7 @@ class MyApp(wx.App):
         self.SpeedWindow1.SetNumberOfSecondaryTicks(5)
 
         # Set The Font For The Ticks Markers
-        self.SpeedWindow1.SetTicksFont(wx.Font(11, wx.SWISS, wx.NORMAL, wx.NORMAL))
+        self.SpeedWindow1.SetTicksFont(wx.Font(13, wx.SWISS, wx.NORMAL, wx.NORMAL))
                                        
         # Set The Text In The Center Of SpeedMeter
         self.SpeedWindow1.SetMiddleText("Km/h")
@@ -576,7 +571,7 @@ class MyApp(wx.App):
         ticks = [str(interval) for interval in intervals]
         self.SpeedWindow5.SetTicks(ticks)
         self.SpeedWindow5.SetTicksColour(wx.WHITE)
-        self.SpeedWindow5.SetTicksFont(wx.Font(11, wx.SWISS, wx.NORMAL, wx.NORMAL))
+        self.SpeedWindow5.SetTicksFont(wx.Font(13, wx.SWISS, wx.NORMAL, wx.NORMAL))
 
         self.SpeedWindow5.SetHandColour(wx.Colour(255, 50, 0))
 
@@ -602,8 +597,8 @@ class MyApp(wx.App):
             self.SpeedWindow5.SetSize(e.GetSize())
 
             w,h = self.frame.GetClientSizeTuple()
-            self.SpeedWindow1.SetDimensions(0,HOFFSET_LIST+10, w/2-5 ,h )
-            self.SpeedWindow5.SetDimensions(w/2,HOFFSET_LIST+10, w/2-5 , h )
+            self.SpeedWindow1.SetDimensions(0,HOFFSET_LIST+12, w/2-7 ,h )
+            self.SpeedWindow5.SetDimensions(w/2+2,HOFFSET_LIST+12, w/2-7 , h )
 
 
         Dialpanel.Bind(wx.EVT_SIZE,OnPSize)
@@ -795,7 +790,8 @@ class MyApp(wx.App):
         stringa = 'dbus-send --print-reply --dest=com.nokia.osso_notes /com/nokia/osso_notes com.nokia.osso_notes.mime_open string:/home/opt/pyobd/pyobd.txt'
         os.popen(stringa)
 
-        Text = """pyobd-0.9.2-17beta
+        Text = """ pyobd-0.9.2-18
+
 Adapted to n900 by m750 at maemo.org
 """
 
